//  The circuit:
//  * input - data fetched from the internet.
//  * output - leds in blue or red.
//  
//  Video link:
//  Created By:
//  Roei Klien 
//  Eden Vilker 309840494


// http request 
#define TINY_GSM_MODEM_ESP8266
#define SerialMon Serial
#define SerialAT Serial1
#define TINY_GSM_RX_BUFFER 1200

// Define the serial console for debug prints, if needed
//#define TINY_GSM_DEBUG SerialMon
// Range to attempt to autobaud
#define GSM_AUTOBAUD_MIN 9600
#define GSM_AUTOBAUD_MAX 115200


#include <Adafruit_CircuitPlayground.h>
#include <TinyGsmClient.h>
// Alarm clock
int melody[] = {262, 294, 330, 349, 392, 440, 494, 523};
int noteDurations[] = {4, 8, 8, 4, 4, 4, 4, 4};

// Your WiFi connection credentials, if applicable
const char wifiSSID[]  = "Eden-Roy";
const char wifiPass[] = "TV242436";

// Server details
const char server[] = "worldtimeapi.org";
const char resource[] = "/api/timezone/Asia/Jerusalem"; 

TinyGsm modem(SerialAT);

TinyGsmClient client(modem);
const int port = 80;

void setup() {
  CircuitPlayground.begin();
//  pinMode(LED_BUILTIN, OUTPUT);
//  pinMode(A1, OUTPUT);
  SerialMon.begin(115200);
  delay(1000);
  SerialAT.begin(115200);
  SerialMon.println("Initializing modem...");
  modem.restart();
  String modemInfo = modem.getModemInfo();
  SerialMon.print("Modem Info: ");
  SerialMon.println(modemInfo);
}

void loop() {
  connect();
  SerialMon.println("connect");
  wakeUp();
  
}

void connect(){
  // Wifi connection parameters must be set before waiting for the network
  SerialMon.print(F("Setting SSID/password..."));
  if (!modem.networkConnect(wifiSSID, wifiPass)) {
    SerialMon.println(" fail");
    delay(5000);
    return;
  }
  SerialMon.println(" success");
  SerialMon.print("Waiting for network...");
  if (!modem.waitForNetwork()) {
    SerialMon.println(" fail");
    delay(5000);
    return;
  }
  SerialMon.println(" success");

  if (modem.isNetworkConnected()) {
    SerialMon.println("Network connected");
  }

  SerialMon.print("Connecting to ");
  SerialMon.println(server);
  if (!client.connect(server, port)) {
    SerialMon.println(" fail");
    delay(10000);
    return;
  }
  SerialMon.println(" success");
}

String getResponseJsonString(){
 //  Make a HTTP GET request:
  SerialMon.println("Performing HTTP GET request...");
  client.print(String("GET ") + resource + " HTTP/1.1\r\n");
  SerialMon.println(String("GET ")+ resource + " HTTP/1.1\r\n");
  client.print(String("Host: ") + server + "\r\n");
  client.print("Connection: close\r\n\r\n");
  client.println();
  SerialMon.println();
  uint32_t timeout = millis();
  String responseJson;
  int nestingDepth = 0;
  String response = "";
  while (client.connected()) {
  while (client.available()) {
    char c = client.read();
    response += c;
    }
    SerialMon.println(response);
  }
  
  return response;
}


void wakeUp(){
  String response = getResponseJsonString();
  SerialMon.println("response");
  SerialMon.println(response);
  int start = response.indexOf("datetime") + 12;
  int end = response.indexOf("+", start);
  String date = response.substring(start,end);
  start = date.indexOf("T") + 1;
  end = date.indexOf("+");
  String hour = date.substring(start,end);
  SerialMon.println("date");
  SerialMon.println(date);
  SerialMon.println(hour);
  SerialMon.println(CircuitPlayground.slideSwitch());
  if (hour >= "06:00" and hour < "06:30" and CircuitPlayground.slideSwitch()){
    for (int thisNote = 0; thisNote < 8; thisNote++) {
      int noteDuration = 1000/noteDurations[thisNote];
      tone(8, melody[thisNote],noteDuration);
      int pauseBetweenNotes = noteDuration * 1.30;
      delay(pauseBetweenNotes);
      noTone(8);
  }
    for (int i=0; i < 10; i++){
       CircuitPlayground.setPixelColor(i, 200, 200, 200);
    }
  } 
  else{
     for (int i=0; i < 10; i++){
       CircuitPlayground.setPixelColor(i, 0, 0, 0);
    }
  }
}

void connectionShutdown(){
  client.stop();
  SerialMon.println(F("Server disconnected"));

  modem.networkDisconnect();
  SerialMon.println(F("WiFi disconnected"));

  // Do nothing forevermore
  while (true) {
    delay(1000);
  }
}
